==> org-lsst-ccs-subsystem-fcs-buses-7.0.0-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByCanOpenDevice.java <==

package org.lsst.ccs.subsystems.fcs;

import org.lsst.ccs.bus.annotations.DataAttributes;

/**
 *
 * Data to be published on the STATUS bus by a CANopen device
 *
 * @author virieux
 */
public class StatusDataPublishedByCanOpenDevice extends StatusDataPublishedByHardware {
    private static final long serialVersionUID = -4729018504834624288L;

    @DataAttributes(description = "device is in error", units = "unitless")
    private boolean inError;

    @DataAttributes(description = "error register read on controller", units = "unitless")
    private String errorRegister;

    @DataAttributes(description = "number of errors read on the controller", units = "unitless")
    private int errorHistoryNB;

    @DataAttributes(description = "code from the last error read on controller", units = "unitless")
    private int lastErrorCode;

    @DataAttributes(description = "name of the last error corresponding to lastErrorCode", units = "unitless")
    private String lastErrorName;

    public StatusDataPublishedByCanOpenDevice(boolean isBooted, boolean isInitialized) {
        super(isBooted, isInitialized);
    }

    public StatusDataPublishedByCanOpenDevice(boolean isBooted, boolean isInitialized,
            boolean inError, String errorRegister,
            int errorHistoryNB, int lastErrorCode, String lastErrorName
    ) {
        super(isBooted, isInitialized);
        this.inError = inError;
        this.errorRegister = errorRegister;
        this.errorHistoryNB = errorHistoryNB;
        this.lastErrorCode = lastErrorCode;
        this.lastErrorName = lastErrorName;
    }


    public boolean isInError() {
        return inError;
    }


    public String getErrorRegister() {
        return errorRegister;
    }


    public int getErrorHistoryNB() {
        return errorHistoryNB;
    }


    public int getLastErrorCode() {
        return lastErrorCode;
    }


    public String getLastErrorName() {
        return lastErrorName;
    }

}

==> org-lsst-ccs-subsystem-fcs-buses-7.0.4-20240719.082618-8-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByCanOpenDevice.java <==

package org.lsst.ccs.subsystems.fcs;

import org.lsst.ccs.bus.annotations.DataAttributes;

/**
 *
 * Data to be published on the STATUS bus by a CANopen device
 *
 * @author virieux
 */
public class StatusDataPublishedByCanOpenDevice extends StatusDataPublishedByHardware {
    private static final long serialVersionUID = -4729018504834624288L;

    @DataAttributes(description = "Device is in error", units = "unitless")
    private boolean inError;

    @DataAttributes(description = "Error register read on controller", units = "unitless")
    private String errorRegister;

    @DataAttributes(description = "Number of errors read on the controller", units = "unitless")
    private int errorHistoryNB;

    @DataAttributes(description = "Code from the last error read on controller", units = "unitless")
    private int lastErrorCode;

    @DataAttributes(description = "Name of the last error corresponding to lastErrorCode", units = "unitless")
    private String lastErrorName;

    public StatusDataPublishedByCanOpenDevice(boolean isBooted, boolean isInitialized) {
        super(isBooted, isInitialized);
    }

    public StatusDataPublishedByCanOpenDevice(boolean isBooted, boolean isInitialized,
            boolean inError, String errorRegister,
            int errorHistoryNB, int lastErrorCode, String lastErrorName
    ) {
        super(isBooted, isInitialized);
        this.inError = inError;
        this.errorRegister = errorRegister;
        this.errorHistoryNB = errorHistoryNB;
        this.lastErrorCode = lastErrorCode;
        this.lastErrorName = lastErrorName;
    }


    public boolean isInError() {
        return inError;
    }


    public String getErrorRegister() {
        return errorRegister;
    }


    public int getErrorHistoryNB() {
        return errorHistoryNB;
    }


    public int getLastErrorCode() {
        return lastErrorCode;
    }


    public String getLastErrorName() {
        return lastErrorName;
    }

}
